@@ -1,4 +1,6 @@
 """This package provides a asynchronous Keycloak Admin API wrapper."""
 
-from .keycloak_admin_aio import KeycloakAdmin
+from ._keycloak_admin_aio import KeycloakAdmin
 from .types import *
+
+__all__ = ["KeycloakAdmin"]
